@@ -101,6 +101,7 @@ class MPStatus(object):
         self.lost_gps_lock = False
         self.last_gps_lock = 0
         self.watch = None
+        self.watch_verbose = False
         self.last_streamrate1 = -1
         self.last_streamrate2 = -1
         self.last_seq = 0
@@ -257,6 +258,7 @@ class MPState(object):
               MPSetting('wpupdates', bool, True, 'Announce waypoint updates'),
               MPSetting('wpterrainadjust', bool, True, 'Adjust alt of moved wp using terrain'),
               MPSetting('wp_use_mission_int', bool, True, 'use MISSION_ITEM_INT messages'),
+              MPSetting('wp_use_waypoint_set_current', bool, False, 'use deprecated WAYPOINT_SET_CURRENT message'),
 
               MPSetting('basealt', int, 0, 'Base Altitude', range=(0,30000), increment=1, tab='Altitude'),
               MPSetting('wpalt', int, 100, 'Default WP Altitude', range=(0,10000), increment=1),
@@ -475,7 +477,14 @@ def cmd_watch(args):
     '''watch a mavlink packet pattern'''
     if len(args) == 0:
         mpstate.status.watch = None
+        mpstate.status.watch_verbose = False
         return
+    if "--verbose" in args:
+        mpstate.status.watch_verbose = True
+        args.remove('--verbose')
+    else:
+        mpstate.status.watch_verbose = False
+
     mpstate.status.watch = args
     print("Watching %s" % mpstate.status.watch)
 
@@ -1278,6 +1287,7 @@ if __name__ == '__main__':
     parser.add_option("--state-basedir", default=None, help="base directory for logs and aircraft directories")
     parser.add_option("--version", action='store_true', help="version information")
     parser.add_option("--default-modules", default="log,signing,wp,rally,fence,ftp,param,relay,tuneopt,arm,mode,calibration,rc,auxopt,misc,cmdlong,battery,terrain,output,adsb,layout", help='default module list')
+    parser.add_option("--udp-timeout",dest="udp_timeout", default=0.0, type='float', help="Timeout for udp clients in seconds")
 
     (opts, args) = parser.parse_args()
     if len(args) != 0:
@@ -1395,7 +1405,11 @@ if __name__ == '__main__':
 
     # open any mavlink output ports
     for port in opts.output:
-        mpstate.mav_outputs.append(mavutil.mavlink_connection(port, baud=int(opts.baudrate), input=False))
+        # cope with older pymavlink
+        if opts.udp_timeout > 0:
+            mpstate.mav_outputs.append(mavutil.mavlink_connection(port, baud=int(opts.baudrate), input=False, udp_timeout=opts.udp_timeout))
+        else:
+            mpstate.mav_outputs.append(mavutil.mavlink_connection(port, baud=int(opts.baudrate), input=False))
 
     if opts.sitl:
         mpstate.sitl_output = mavutil.mavudp(opts.sitl, input=False)
