@@ -485,7 +485,7 @@ class MagFit(MPDataLogChildTask):
 
 class MagFitUI(wx.Dialog):
     def __init__(self, title, close_event, mlog, timestamp_in_range):
-        super(MagFitUI, self).__init__(None, title=title, size=(600, 800))
+        super(MagFitUI, self).__init__(None, title=title, size=(600, 800), style=wx.DEFAULT_DIALOG_STYLE|wx.RESIZE_BORDER)
 
         # capture the close event, log and timestamp range function
         self.close_event = close_event
@@ -569,8 +569,8 @@ class MagFitUI(wx.Dialog):
         self.AddSpinInteger("OffsetMax", 500, 3000, 1500)
 
         self.StartRow('Scale Factor Estimation')
-        self.AddSpinFloat("ScaleMin", 0.5, 2.0, 0.01, 1.0)
-        self.AddSpinFloat("ScaleMax", 0.5, 2.0, 0.01, 1.0)
+        self.AddSpinFloat("ScaleMin", 0.25, 4.0, 0.01, 1.0)
+        self.AddSpinFloat("ScaleMax", 0.25, 4.0, 0.01, 1.0)
 
         self.StartRow('Elliptical Estimation')
         self.AddCheckBox("Elliptical")
