@@ -75,6 +75,7 @@ class ConsoleModule(mp_module.MPModule):
         mpstate.console.set_status('Mission', 'Mission --/--', row=3)
 
         self.vehicle_list = []
+        self.vehicle_heartbeats = {}  # map from (sysid,compid) tuple to most recent HEARTBEAT nessage
         self.vehicle_menu = None
         self.vehicle_name_by_sysid = {}
         self.component_name = {}
@@ -249,15 +250,30 @@ class ConsoleModule(mp_module.MPModule):
 
     def check_critical_error(self, msg):
         '''check for any error bits being set in SYS_STATUS'''
+        sysid = msg.get_srcSystem()
+        compid = msg.get_srcComponent()
+        hb = self.vehicle_heartbeats.get((sysid, compid), None)
+        if hb is None:
+            return
+        # only ArduPilot populates the fields with internal error stuff:
+        if hb.autopilot != mavutil.mavlink.MAV_AUTOPILOT_ARDUPILOTMEGA:
+            return
+
         errors = msg.errors_count1 | (msg.errors_count2<<16)
         if errors == 0:
             return
         now = time.time()
         if now - self.last_sys_status_errors_announce > self.mpstate.settings.sys_status_error_warn_interval:
             self.last_sys_status_errors_announce = now
-            self.say("Critical failure 0x%x sysid=%u" % (errors, msg.get_srcSystem()))
+            self.say("Critical failure 0x%x sysid=%u compid=%u" % (errors, sysid, compid))
+
+    def set_component_name(self, sysid, compid, name):
+        if sysid not in self.component_name:
+            self.component_name[sysid] = {}
+        if compid not in self.component_name[sysid]:
+            self.component_name[sysid][compid] = name
+            self.update_vehicle_menu()
 
-        
     def mavlink_packet(self, msg):
         '''handle an incoming mavlink packet'''
         if not isinstance(self.console, wxconsole.MessageConsole):
@@ -269,14 +285,15 @@ class ConsoleModule(mp_module.MPModule):
         sysid = msg.get_srcSystem()
         compid = msg.get_srcComponent()
 
-        if type == 'HEARTBEAT' or type == 'HIGH_LATENCY2':
+        if type in frozenset(['HEARTBEAT', 'HIGH_LATENCY2']):
+            if type == 'HEARTBEAT':
+                self.vehicle_heartbeats[(sysid, compid)] = msg
             if not sysid in self.vehicle_list:
                 self.add_new_vehicle(msg)
-            if sysid not in self.component_name:
-                self.component_name[sysid] = {}
-            if compid not in self.component_name[sysid]:
-                self.component_name[sysid][compid] = self.component_type_string(msg)
-                self.update_vehicle_menu()
+            self.set_component_name(sysid, compid, self.component_type_string(msg))
+        elif type == 'GIMBAL_DEVICE_INFORMATION':
+            self.set_component_name(sysid, compid, "%s-%s" %
+                                    (msg.vendor_name, msg.model_name))
 
         if self.last_param_sysid_timestamp != self.module('param').new_sysid_timestamp:
             '''a new component ID has appeared for parameters'''
@@ -316,6 +333,14 @@ class ConsoleModule(mp_module.MPModule):
                 self.console.set_status(field, '%s %u (%u)' % (prefix, fix_type, nsats), fg='red')
             if type == 'GPS_RAW_INT':
                 vfr_hud_heading = master.field('VFR_HUD', 'heading', None)
+                if vfr_hud_heading is None:
+                    # try to fill it in from GLOBAL_POSITION_INT instead:
+                    vfr_hud_heading = master.field('GLOBAL_POSITION_INT', 'hdg', None)
+                    if vfr_hud_heading is not None:
+                        if vfr_hud_heading == 65535:  # mavlink magic "unknown" value
+                            vfr_hud_heading = None
+                        else:
+                            vfr_hud_heading /= 100
                 gps_heading = int(msg.cog * 0.01)
                 if vfr_hud_heading is None:
                     vfr_hud_heading = '---'
@@ -395,8 +420,9 @@ class ConsoleModule(mp_module.MPModule):
                         'LOG'  : mavutil.mavlink.MAV_SYS_STATUS_LOGGING,
                         'PRX'  : mavutil.mavlink.MAV_SYS_STATUS_SENSOR_PROXIMITY,
                         'PRE'  : mavutil.mavlink.MAV_SYS_STATUS_PREARM_CHECK,
+                        'FLO'  : mavutil.mavlink.MAV_SYS_STATUS_SENSOR_OPTICAL_FLOW,
             }
-            hide_if_not_present = set(['PRE', 'PRX'])
+            hide_if_not_present = set(['PRE', 'PRX', 'FLO'])
             for s in sensors.keys():
                 bits = sensors[s]
                 present = ((msg.onboard_control_sensors_present & bits) == bits)
@@ -465,13 +491,12 @@ class ConsoleModule(mp_module.MPModule):
                 fg = 'green'
             self.console.set_status('EKF', 'EKF', fg=fg)
 
-        elif type == 'HWSTATUS':
+        elif type == 'POWER_STATUS':
             if msg.Vcc >= 4600 and msg.Vcc <= 5300:
                 fg = 'green'
             else:
                 fg = 'red'
             self.console.set_status('Vcc', 'Vcc %.2f' % (msg.Vcc * 0.001), fg=fg)
-        elif type == 'POWER_STATUS':
             if msg.flags & mavutil.mavlink.MAV_POWER_STATUS_CHANGED:
                 fg = 'red'
             else:
