@@ -106,8 +106,8 @@ class FTPModule(mp_module.MPModule):
              ('pkt_loss_tx', int, 0),
              ('pkt_loss_rx', int, 0),
              ('max_backlog', int, 5),
-             ('burst_read_size', int, 110),
-             ('write_size', int, 110),
+             ('burst_read_size', int, 80),
+             ('write_size', int, 80),
              ('write_qsize', int, 5),
              ('retry_time', float, 0.5)])
         self.add_completion_function('(FTPSETTING)',
@@ -714,6 +714,11 @@ class FTPModule(mp_module.MPModule):
         '''handle a mavlink packet'''
         mtype = m.get_type()
         if mtype == "FILE_TRANSFER_PROTOCOL":
+            if (m.target_system != self.settings.source_system or
+                m.target_component != self.settings.source_component):
+                # this is not for me
+                return
+
             op = self.op_parse(m)
             now = time.time()
             dt = now - self.last_op_time
