@@ -9,6 +9,11 @@
 from pymavlink import mavutil
 import time, struct, math, sys, fnmatch, traceback, json, os
 
+if sys.version_info[0] >= 3:
+    import io as StringIO
+else:
+    import StringIO
+
 from MAVProxy.modules.lib import mp_module
 from MAVProxy.modules.lib import mp_util
 
@@ -445,13 +450,31 @@ class LinkModule(mp_module.MPModule):
         '''time since 1970 in microseconds'''
         return int(time.time() * 1.0e6)
 
+    def dump_message_verbose(self, m):
+        '''return verbose dump of m.  Wraps the pymavlink routine which
+        inconveniently takes a filehandle'''
+        f = StringIO.StringIO()
+        mavutil.dump_message_verbose(f, m)
+        return f.getvalue()
+
+    def check_watched_message(self, m, direction_string):
+        '''if we are watching a message, print it out'''
+        if self.status.watch is None:
+            return
+        mtype = m.get_type().upper()
+        for msg_type in self.status.watch:
+            if not fnmatch.fnmatch(mtype, msg_type.upper()):
+                continue
+            if self.status.watch_verbose:
+                message_string = self.dump_message_verbose(m)
+            else:
+                message_string = str(m)
+            self.mpstate.console.writeln(direction_string + ' ' + message_string)
+            break
+
     def master_send_callback(self, m, master):
         '''called on sending a message'''
-        if self.status.watch is not None:
-            for msg_type in self.status.watch:
-                if fnmatch.fnmatch(m.get_type().upper(), msg_type.upper()):
-                    self.mpstate.console.writeln('> '+ str(m))
-                    break
+        self.check_watched_message(m, '>')
 
         mtype = m.get_type()
         if mtype != 'BAD_DATA' and self.mpstate.logqueue:
@@ -539,6 +562,56 @@ class LinkModule(mp_module.MPModule):
             self.status.last_apm_msg_time = time.time()
         del self.status.statustexts_by_sysidcompid[key][id]
 
+    def heartbeat_is_from_autopilot(self, m):
+        '''returns true if m is a HEARTBEAT (or HIGH_LATENCY2) message and
+        looks like it is from an actual autopilot rather than from e.g. a
+        mavlink-connected camera'''
+
+        mtype = m.get_type()
+
+        if mtype not in ['HEARTBEAT', 'HIGH_LATENCY2']:
+            return False
+
+        mav_autopilots_which_are_not_vehicles = frozenset([
+            'MAV_AUTOPILOT_INVALID',
+            'MAV_AUTOPILOT_RESERVED',
+        ])
+        if m.autopilot in mav_autopilots_which_are_not_vehicles:
+            return False
+
+        # this is a rather bogus assumption - and might break people's
+        # setups.  It should probably be removed in favour of trusting
+        # the MAV_TYPE field.
+        component_ids_which_are_not_vehicles = frozenset([
+            mavutil.mavlink.MAV_COMP_ID_ADSB,
+            mavutil.mavlink.MAV_COMP_ID_ODID_TXRX_1,
+            mavutil.mavlink.MAV_COMP_ID_ODID_TXRX_2,
+            mavutil.mavlink.MAV_COMP_ID_ODID_TXRX_3
+        ])
+        if m.get_srcComponent() in component_ids_which_are_not_vehicles:
+            return False
+
+        mav_types_which_are_not_vehicles = frozenset([
+            mavutil.mavlink.MAV_TYPE_GCS,
+            mavutil.mavlink.MAV_TYPE_ONBOARD_CONTROLLER,
+            mavutil.mavlink.MAV_TYPE_GIMBAL,
+            mavutil.mavlink.MAV_TYPE_ADSB,
+            mavutil.mavlink.MAV_TYPE_CAMERA,
+            mavutil.mavlink.MAV_TYPE_CHARGING_STATION,
+            mavutil.mavlink.MAV_TYPE_SERVO,
+            mavutil.mavlink.MAV_TYPE_ODID,
+            mavutil.mavlink.MAV_TYPE_BATTERY,
+            mavutil.mavlink.MAV_TYPE_LOG,
+            mavutil.mavlink.MAV_TYPE_OSD,
+            mavutil.mavlink.MAV_TYPE_IMU,
+            mavutil.mavlink.MAV_TYPE_GPS,
+            mavutil.mavlink.MAV_TYPE_WINCH,
+        ])
+        if m.type in mav_types_which_are_not_vehicles:
+            return False
+
+        return True
+
     def master_msg_handling(self, m, master):
         '''link message handling for an upstream link'''
         if self.settings.target_system != 0 and m.get_srcSystem() != self.settings.target_system:
@@ -562,19 +635,14 @@ class LinkModule(mp_module.MPModule):
             
         mtype = m.get_type()
 
-        if (mtype == 'HEARTBEAT' or mtype == 'HIGH_LATENCY2') and m.type != mavutil.mavlink.MAV_TYPE_GCS:
+        if self.heartbeat_is_from_autopilot(m):
             if self.settings.target_system == 0 and self.settings.target_system != m.get_srcSystem():
                 self.settings.target_system = m.get_srcSystem()
+                self.settings.target_component = m.get_srcComponent()
                 self.say("online system %u" % self.settings.target_system,'message')
                 for mav in self.mpstate.mav_master:
                     mav.target_system = self.settings.target_system
-
-            if m.get_srcComponent() in [mavutil.mavlink.MAV_COMP_ID_ADSB,
-                                        mavutil.mavlink.MAV_COMP_ID_ODID_TXRX_1,
-                                        mavutil.mavlink.MAV_COMP_ID_ODID_TXRX_2,
-                                        mavutil.mavlink.MAV_COMP_ID_ODID_TXRX_3]:
-                # ignore these
-                return
+                    mav.target_component = self.settings.target_component
 
             if self.status.heartbeat_error:
                 self.status.heartbeat_error = False
@@ -669,7 +737,10 @@ class LinkModule(mp_module.MPModule):
                         if chunk_seq != next_expected_chunk:
                             out += " ... "
                             next_expected_chunk = chunk_seq
-                        out += self.chunks[chunk_seq]
+                        if isinstance(self.chunks[chunk_seq], str):
+                            out += self.chunks[chunk_seq]
+                        else:
+                            out += self.chunks[chunk_seq].decode(errors="ignore")
                         next_expected_chunk += 1
 
                     return out
@@ -766,6 +837,9 @@ class LinkModule(mp_module.MPModule):
                     self.say("Calibration failed")
                 elif m.result == mavutil.mavlink.MAV_RESULT_UNSUPPORTED:
                     self.say("Calibration unsupported")
+                elif m.result == mavutil.mavlink.MAV_RESULT_IN_PROGRESS:
+                    # don't bother the user with this
+                    pass
                 elif m.result == mavutil.mavlink.MAV_RESULT_TEMPORARILY_REJECTED:
                     self.say("Calibration temporarily rejected")
                 else:
@@ -783,11 +857,7 @@ class LinkModule(mp_module.MPModule):
             #self.mpstate.console.writeln("Got MAVLink msg: %s" % m)
             pass
 
-        if self.status.watch is not None:
-            for msg_type in self.status.watch:
-                if fnmatch.fnmatch(mtype.upper(), msg_type.upper()):
-                    self.mpstate.console.writeln('< '+ str(m))
-                    break
+        self.check_watched_message(m, '<')
 
     def mavlink_packet(self, msg):
         '''handle an incoming mavlink packet'''
