@@ -89,6 +89,7 @@ class MapModule(mp_module.MPModule):
         self.add_menu(MPMenuItem('Set Origin (with height)', 'Set Origin', '# map setorigin '))
         self.add_menu(MPMenuItem('Terrain Check', 'Terrain Check', '# terrain check'))
         self.add_menu(MPMenuItem('Show Position', 'Show Position', 'showPosition'))
+        self.add_menu(MPMenuItem('Google Maps Link', 'Google Maps Link', 'printGoogleMapsLink'))
         self.add_menu(MPMenuItem('Set ROI', 'Set ROI', '# map setroi '))
 
         self._colour_for_wp_command = {
@@ -143,6 +144,11 @@ class MapModule(mp_module.MPModule):
         posbox = MPMenuChildMessageDialog('Position', msg, font_size=32)
         posbox.show()
 
+    def print_google_maps_link(self):
+        '''show map position click information'''
+        pos = self.mpstate.click_location
+        print("https://www.google.com/maps/search/?api=1&query=%f,%f" % (pos[0], pos[1]))
+
     def cmd_map(self, args):
         '''map commands'''
         from MAVProxy.modules.mavproxy_map import mp_slipmap
@@ -472,6 +478,8 @@ class MapModule(mp_module.MPModule):
             self.move_fencepoint(obj.selected[0].objkey, obj.selected[0].extra_info)
         elif menuitem.returnkey == 'showPosition':
             self.show_position()
+        elif menuitem.returnkey == 'printGoogleMapsLink':
+            self.print_google_maps_link()
         elif menuitem.returnkey == 'setServiceTerrain':
             self.module('terrain').cmd_terrain(['set', 'source', menuitem.get_choice()])
 
@@ -624,16 +632,18 @@ class MapModule(mp_module.MPModule):
         (lat, lon) = (self.mpstate.click_location[0], self.mpstate.click_location[1])
         alt = self.module('terrain').ElevationModel.GetElevation(lat, lon)
         print("Setting ROI to: ", lat, lon, alt)
-        self.master.mav.command_long_send(
+        self.master.mav.command_int_send(
             self.settings.target_system, self.settings.target_component,
+            mavutil.mavlink.MAV_FRAME_GLOBAL,
             mavutil.mavlink.MAV_CMD_DO_SET_ROI_LOCATION,
-            0, # confirmation
+            0, # current
+            0, # autocontinue
             0, # param1
             0, # param2
             0, # param3
             0, # param4
-            lat, # lat
-            lon, # lon
+            int(lat*1e7), # lat
+            int(lon*1e7), # lon
             alt) # param7
         
     def cmd_set_origin(self, args):
