@@ -66,7 +66,8 @@ TILE_SERVICES = {
     "OpenAerialMap"  : "http://tile.openaerialmap.org/tiles/?v=mgm&layer=openaerialmap-900913&x=${X}&y=${Y}&zoom=${OAM_ZOOM}",
     "OpenCycleMap"   : "http://andy.sandbox.cloudmade.com/tiles/cycle/${ZOOM}/${X}/${Y}.png",
     "Eniro DK,NO,SE,FI,PL" : "http://map.eniro.com/geowebcache/service/tms1.0.0/map/${ZOOM}/${X}/${ENI_Y}.png",
-    "StatKartTopo2" : "http://opencache.statkart.no/gatekeeper/gk/gk.open_gmaps?layers=topo4&zoom=${ZOOM}&x=${X}&y=${Y}"
+    "StatkartTopo" : "http://opencache.statkart.no/gatekeeper/gk/gk.open_gmaps?layers=topo4&zoom=${ZOOM}&x=${X}&y=${Y}",
+    "StatkartBasemap" : "http://opencache.statkart.no/gatekeeper/gk/gk.open_gmaps?layers=norgeskart_bakgrunn&zoom=${ZOOM}&x=${X}&y=${Y}"
 
     }
 
@@ -367,6 +368,8 @@ class MPTile:
                     continue
             else:
                 path = self.tile_to_path(tile_info)
+                if not os.path.exists(path):
+                    continue
                 img = cv2.imread(path)
                 if img is None:
                     continue
@@ -407,7 +410,10 @@ class MPTile:
 
 
         path = self.tile_to_path(tile)
-        ret = cv2.imread(path)
+        if not os.path.exists(path):
+            ret = None
+        else:
+            ret = cv2.imread(path)
         if ret is not None:
             #cv2.rectangle(ret, (0,0), (TILES_WIDTH-1,TILES_WIDTH-1), (255,0,0), 1)
             # if it is an old tile, then try to refresh
