@@ -106,6 +106,8 @@ class MiscModule(mp_module.MPModule):
         self.add_command('formatsdcard', self.cmd_formatsdcard, "format SD card")
         self.add_command('canforward', self.cmd_canforward, "enable CAN forwarding")
 
+        self.add_command('gear', self.cmd_landing_gear, "landing gear control")
+        
         self.repeats = []
 
     def altitude_difference(self, pressure1, pressure2, ground_temp):
@@ -157,6 +159,33 @@ class MiscModule(mp_module.MPModule):
 
     def cmd_reboot(self, args):
         '''reboot autopilot'''
+
+        hold_in_bootloader = "bootloader" in args
+        force = "force" in args
+
+        # different path for force/not force to avoid dependency on
+        # pymavlink's force-reboot support:
+        if force:
+            if hold_in_bootloader:
+                param1 = 3
+            else:
+                param1 = 1
+            param6 = 20190226
+            self.master.mav.command_long_send(
+                self.target_system,
+                self.target_component,
+                mavutil.mavlink.MAV_CMD_PREFLIGHT_REBOOT_SHUTDOWN,
+                0,
+                param1,
+                0,
+                0,
+                0,
+                0,
+                param6,
+                0
+            )
+            return
+
         if len(args) > 0 and args[0] == 'bootloader':
             self.master.reboot_autopilot(True)
         else:
@@ -261,7 +290,7 @@ class MiscModule(mp_module.MPModule):
     def cmd_changealt_abs(self, args):
         '''change target altitude'''
         if len(args) < 1:
-            print("usage: changealt <relaltitude>")
+            print("usage: changealt_abs <absaltitude>")
             return
         absalt = float(args[0])
         self.master.mav.mission_item_send(self.settings.target_system,
@@ -290,8 +319,12 @@ class MiscModule(mp_module.MPModule):
 
     def cmd_version(self, args):
         '''show version'''
-        self.master.mav.autopilot_version_request_send(self.settings.target_system,
-                                                       self.settings.target_component)
+        self.master.mav.command_long_send(
+            self.settings.target_system,
+            self.settings.target_component,
+            mavutil.mavlink.MAV_CMD_REQUEST_MESSAGE,
+            0, # confirmation
+            mavutil.mavlink.MAVLINK_MSG_ID_AUTOPILOT_VERSION, 0, 0, 0, 0, 0, 0)
 
     def cmd_capabilities(self, args):
         '''show capabilities'''
@@ -567,7 +600,41 @@ class MiscModule(mp_module.MPModule):
             0,
             0,
             0)
-        
+    
+    def cmd_landing_gear(self, args):
+        usage='''Usage: gear <up|down> [ID]
+Alt: gear <extend|retract> [ID]'''
+        if len(args) == 0 or args[0] not in ['up','down','extend', 'retract']:
+            print(usage)
+            return
+        if args[0] in ['down','extend']:
+            DesiredState=0
+        elif args [0] in ['up','retract']:
+            DesiredState=1
+        else:
+            print(usage)
+            return
+        if len(args)==1:
+            ID=-1
+        elif len(args)==2:
+            try:
+                ID=int(args[1])
+            except ValueError:
+                print(usage)
+                return
+            if ID<-1:
+                print(usage)
+                return
+        else:
+            print(usage)
+            return
+        self.master.mav.command_long_send(self.target_system,
+                                               self.target_component,
+                                               mavutil.mavlink.MAV_CMD_AIRFRAME_CONFIGURATION , 0, 
+                                               ID,
+                                               DesiredState,
+                                               0, 0, 0, 0, 0, 0)
+    
     def idle_task(self):
         '''called on idle'''
         for r in self.repeats:
