@@ -16,7 +16,7 @@
 #
 # Responsible  : Jaime Machuca
 #
-# License      : CC BY-NC-SA
+# License      : GNU GPL version 3
 #
 # Editor Used  : Xcode 6.1.1 (6A2008a)
 #
@@ -27,7 +27,7 @@
 #****************************************************************************
 
 # System Header files and Module Headers
-import time, math, sched
+import time, math, sched, threading
 
 # Module Dependent Headers
 from pymavlink import mavutil
@@ -66,10 +66,10 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
-    
+
     def __init__(self, mpstate):
         super(SmartCameraModule, self).__init__(mpstate, "SmartCamera", "SmartCamera commands")
         self.add_command('camtrigger', self.__vCmdCamTrigger, "Trigger camera")
@@ -78,6 +78,7 @@ class SmartCameraModule(mp_module.MPModule):
         self.add_command('setCamAperture', self.__vCmdSetCamAperture, "Set Camera Aperture")
         self.add_command('setCamShutterSpeed', self.__vCmdSetCamShutterSpeed, "Set Camera Shutter Speed")
         self.add_command('setCamExposureMode', self.__vCmdSetCamExposureMode, "Set Camera Exposure Mode")
+        self.add_command('getAllPictures', self.__vCmdGetAllPictures, "Download all flight pictures, filename as argument optional")
         self.CamRetryScheduler = sched.scheduler(time.time, time.sleep)
         self.ProgramAuto = 1
         self.Aperture = 2
@@ -85,11 +86,39 @@ class SmartCameraModule(mp_module.MPModule):
         self.Manual = 4
         self.IntelligentAuto = 5
         self.SuperiorAuto = 6
-        self.WirelessPort = "wlan0"
+        self.WirelessPort = sc_config.config.get_string("general", 'WirelessPort', "wlan0")
         self.u8RetryTimeout = 0
         self.u8MaxRetries = 5
+        self.tLastCheckTime = time.time()
+        self.u8KillHeartbeatTimer = 100
         self.__vRegisterCameras()
- 
+
+        self.mpstate = mpstate
+        
+        # Start a 10 second timer to kill heartbeats as a workaround
+        # threading.Timer(10, self.__vKillHeartbeat).start()
+    
+#****************************************************************************
+#   Method Name     : __vKillHeartbeat
+#
+#   Description     : Sets heartbeat setting to 0 to stop sending heartbeats
+#                     this is a temporary workaround for systems that do not
+#                     properly interpret the heartbeat contents like 3DR Solo
+#                     in such systems the heartbeats from the camera controller
+#                     and the main system are confused causing potential issues
+#
+#   Parameters      : None
+#
+#   Return Value    : None
+#
+#   Author           : Jaime Machuca
+#
+#****************************************************************************
+
+    def __vKillHeartbeat(self):
+        print("Killing Heartbeat - Solo Workaround")
+        self.mpstate.settings.heartbeat = 0
+
  #****************************************************************************
  #   Method Name     : __vRegisterQXCamera
  #
@@ -101,7 +130,7 @@ class SmartCameraModule(mp_module.MPModule):
  #
  #   Return Value    : None
  #
- #   Autor           : Jaime Machuca
+ #   Author           : Jaime Machuca
  #
  #****************************************************************************
 
@@ -111,6 +140,7 @@ class SmartCameraModule(mp_module.MPModule):
             if new_camera.boValidCameraFound() is True:
                 self.camera_list = self.camera_list + [new_camera]
                 print("Found QX Camera")
+                self.master.mav.statustext_send(6,"Camera Controller: Found QX Camera, Ready to Fly")
             else:
                 print("No Valid Camera Found, retry in 5 sec")
                 self.u8RetryTimeout = self.u8RetryTimeout + 1
@@ -118,6 +148,7 @@ class SmartCameraModule(mp_module.MPModule):
                 self.CamRetryScheduler.run()
         else:
             print("Max retries reached, No QX Camera Found")
+            self.master.mav.statustext_send(3,"Camera Controller: Warning! Camera not found")
             self.u8RetryTimeout = 0
 
 #****************************************************************************
@@ -129,15 +160,15 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
     def __vRegisterCameras(self):
-        
+
         # initialise list
         self.camera_list = []
-        
+
         #look for up to 2 cameras
         for i in range(0,2):
             config_group = "camera%d" % i
@@ -146,11 +177,11 @@ class SmartCameraModule(mp_module.MPModule):
             if camera_type == 1:
                 new_camera = SmartCameraWebCam(i)
                 self.camera_list = self.camera_list + [new_camera]
-            
+
             # Sony QX1
             if camera_type == 2:
                 self.__vRegisterQXCamera(i)
-    
+
         # display number of cameras found
         print ("cameras found: %d" % len(self.camera_list))
 
@@ -163,7 +194,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -183,7 +214,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -205,7 +236,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -229,7 +260,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -253,7 +284,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -277,7 +308,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -301,14 +332,14 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
     def __vCmdCamZoomIn(self):
         for cam in self.camera_list:
             cam.boZoomIn()
- 
+
 #****************************************************************************
 #   Method Name     : __vCmdCamZoomOut
 #
@@ -318,14 +349,40 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
     def __vCmdCamZoomOut(self):
         for cam in self.camera_list:
             cam.boZoomOut()
- 
+
+#****************************************************************************
+#   Method Name     : __vCmdGetAllPictures
+#
+#   Description     : Downloads all the pics taken during this flight
+#
+#   Parameters      : None
+#
+#   Return Value    : None
+#
+#   Author           : Jaime Machuca
+#
+#****************************************************************************
+
+    def __vCmdGetAllPictures(self, args):
+        
+        #Download Pictures
+        if len(args) >= 1:
+            slogFileName = args[0]
+            for cam in self.camera_list:
+                print("Init Picture Download for Cam %s from file %s" % cam, slogFileName)
+                cam.boGetAllSessionPictures(slogFileName)
+        else:
+            for cam in self.camera_list:
+                print("Init Picture Download for Cam %s" % cam)
+                cam.boGetAllSessionPictures(0)
+    
 #****************************************************************************
 #   Method Name     : __vDecodeDIGICAMConfigure
 #
@@ -335,20 +392,20 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
     def __vDecodeDIGICAMConfigure(self, mCommand_Long):
         if mCommand_Long.param1 != 0:
             print ("Exposure Mode = %d" % mCommand_Long.param1)
-            
+
             if mCommand_Long.param1 == self.ProgramAuto:
                 self.__vCmdSetCamExposureMode(["Program Auto"])
-            
+
             elif mCommand_Long.param1 == self.Aperture:
                 self.__vCmdSetCamExposureMode(["Aperture"])
-            
+
             elif mCommand_Long.param1 == self.Shutter:
                 self.__vCmdSetCamExposureMode(["Shutter"])
 
@@ -356,7 +413,7 @@ class SmartCameraModule(mp_module.MPModule):
         if mCommand_Long.param2 != 0:
             print ("Shutter Speed= %d" % mCommand_Long.param2)
             self.__vCmdSetCamShutterSpeed([mCommand_Long.param2])
-        
+
         '''Aperture'''
         if mCommand_Long.param3 != 0:
             print ("Aperture = %d" % mCommand_Long.param3)
@@ -381,7 +438,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -389,11 +446,11 @@ class SmartCameraModule(mp_module.MPModule):
         '''Session'''
         if mCommand_Long.param1 != 0:
             print ("Session = %d" % mCommand_Long.param1)
-        
+
         '''Zooming Step Value'''
         if mCommand_Long.param2 != 0:
             print ("Zooming Step = %d" % mCommand_Long.param2)
-        
+
         '''Zooming Step Value'''
         if mCommand_Long.param3 != 0:
             print ("Zooming Value = %d" % mCommand_Long.param3)
@@ -404,11 +461,11 @@ class SmartCameraModule(mp_module.MPModule):
                 self.__vCmdCamZoomOut()
             else:
                 print ("Invalid Zoom Value")
-        
+
         '''Focus 0=Unlock/1=Lock/2=relock'''
         if mCommand_Long.param4 != 0:
             print ("Focus = %d" % mCommand_Long.param4)
-        
+
         '''Trigger'''
         if mCommand_Long.param5 != 0:
             print ("Trigger = %d" % mCommand_Long.param5)
@@ -419,14 +476,14 @@ class SmartCameraModule(mp_module.MPModule):
 #****************************************************************************
 #   Method Name     : mavlink_packet
 #
-#   Description     : MAVProxy requiered callback function used to recieve MAVlink
+#   Description     : MAVProxy requiered callback function used to receive MAVlink
 #                     packets
 #
 #   Parameters      : MAVLink Message
 #
 #   Return Value    : None
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
@@ -452,6 +509,27 @@ class SmartCameraModule(mp_module.MPModule):
                 print ("Got Message Digicam_control")
                 self.__vDecodeDIGICAMControl(m)
 
+#****************************************************************************
+#   Method Name     : idle_task
+#
+#   Description     : used for heartbeat work arround timer
+#
+#   Parameters      : none
+#
+#   Return Value    : none
+#
+#   Author           : Jaime Machuca
+#
+#****************************************************************************
+
+    def idle_task(self):
+        now = time.time()
+        if not self.u8KillHeartbeatTimer == 0 and self.tLastCheckTime > 1:
+            self.tLastCheckTime = now
+            self.u8KillHeartbeatTimer -= 1
+            if self.u8KillHeartbeatTimer == 0:
+                self.__vKillHeartbeat();
+
 #****************************************************************************
 #   Method Name     : init
 #
@@ -461,7 +539,7 @@ class SmartCameraModule(mp_module.MPModule):
 #
 #   Return Value    : SmartCameraModule Instance
 #
-#   Autor           : Jaime Machuca
+#   Author           : Jaime Machuca
 #
 #****************************************************************************
 
