@@ -31,7 +31,6 @@ class WPModule(mp_module.MPModule):
         self.undo_type = None
         self.undo_wp_idx = -1
         self.upload_start = None
-        self.wploader.expected_count = 0
         self.last_get_home = time.time()
         self.add_command('wp', self.cmd_wp,       'waypoint management',
                          ["<list|clear|move|remove|loop|set|undo|movemulti|moverelhome|changealt|param|status|slope|ftp|add_takeoff|add_landing|add_dls|add_rtl>",
@@ -39,6 +38,9 @@ class WPModule(mp_module.MPModule):
         self.mission_ftp_name = "@MISSION/mission.dat"
         self.ftp_count = None
 
+        # support for setting mission waypoint via command
+        self.accepts_DO_SET_MISSION_CURRENT = {}  # keyed by (sysid/compid)
+
         if self.continue_mode and self.logdir is not None:
             waytxt = os.path.join(mpstate.status.logdir, 'way.txt')
             if os.path.exists(waytxt):
@@ -79,6 +81,7 @@ class WPModule(mp_module.MPModule):
         '''per-sysid wploader'''
         if self.target_system not in self.wploader_by_sysid:
             self.wploader_by_sysid[self.target_system] = mavwp.MAVWPLoader()
+            self.wploader_by_sysid[self.target_system].expected_count = 0
         return self.wploader_by_sysid[self.target_system]
 
     def missing_wps_to_request(self):
@@ -122,15 +125,18 @@ class WPModule(mp_module.MPModule):
         '''handle an incoming mavlink packet'''
         mtype = m.get_type()
         if mtype in ['WAYPOINT_COUNT','MISSION_COUNT']:
-            self.wploader.expected_count = m.count
+            if getattr(m, 'mission_type', 0) != 0:
+                # this is not a mission item, likely fence
+                return
             if self.wp_op is None:
-                #self.console.error("No waypoint load started")
-                pass
+                if self.wploader.expected_count != m.count:
+                    self.console.writeln("Mission is stale")
             else:
                 self.wploader.clear()
                 self.console.writeln("Requesting %u waypoints t=%s now=%s" % (m.count,
                                                                                  time.asctime(time.localtime(m._timestamp)),
                                                                                  time.asctime()))
+                self.wploader.expected_count = m.count
                 self.send_wp_requests()
 
         elif mtype in ['WAYPOINT', 'MISSION_ITEM', 'MISSION_ITEM_INT'] and self.wp_op is not None:
@@ -185,6 +191,18 @@ class WPModule(mp_module.MPModule):
                     if alt_offset > 0.005:
                         self.say("ALT OFFSET IS NOT ZERO passing DO_LAND_START")
 
+        elif mtype == "COMMAND_ACK":
+            # check to see if the vehicle has bounced our attempts to
+            # set the current mission item via mavlink command (as
+            # opposed to the old message):
+            if m.command == mavutil.mavlink.MAV_CMD_DO_SET_MISSION_CURRENT:
+                key = (m.get_srcSystem(), m.get_srcComponent())
+                if m.result == mavutil.mavlink.MAV_RESULT_UNSUPPORTED:
+                    # stop sending the commands:
+                    self.accepts_DO_SET_MISSION_CURRENT[key] = False
+                elif m.result in [ mavutil.mavlink.MAV_RESULT_ACCEPTED ]:
+                    self.accepts_DO_SET_MISSION_CURRENT[key] = True
+
     def idle_task(self):
         '''handle missing waypoints'''
         if self.wp_period.trigger():
@@ -731,7 +749,27 @@ class WPModule(mp_module.MPModule):
             if len(args) != 2:
                 print("usage: wp set <wpindex>")
                 return
-            self.master.waypoint_set_current_send(int(args[1]))
+            # At time of writing MAVProxy sends to (1, 0) by default,
+            # but ArduPilot will respond from (1,1) by default -and
+            # that means COMMAND_ACK handling will fill
+            # self.accepts_DO_SET_MISSION_CURRENT for (1, 1) and we
+            # will not get that value here:
+            key = (self.target_system, self.target_component)
+            supports = self.accepts_DO_SET_MISSION_CURRENT.get(key, None)
+            # if we don't know, send both.  If we do know, send only one.
+            # we "know" because we hook receipt of COMMAND_ACK.
+
+            if self.settings.wp_use_waypoint_set_current or supports is False:
+                self.master.waypoint_set_current_send(int(args[1]))
+            else:
+                self.master.mav.command_long_send(
+                    self.target_system,
+                    self.target_component,
+                    mavutil.mavlink.MAV_CMD_DO_SET_MISSION_CURRENT,
+                    0,
+                    int(args[1]), 0, 0, 0, 0, 0, 0
+                )
+
         elif args[0] == "split":
             self.cmd_split(args[1:])
         elif args[0] == "clear":
