@@ -26,6 +26,7 @@ from pymavlink.mavextra import *
 from MAVProxy.modules.lib.mp_menu import *
 import MAVProxy.modules.lib.mp_util as mp_util
 from pymavlink import mavutil
+from pymavlink import mavwp
 from MAVProxy.modules.lib.mp_settings import MPSettings, MPSetting
 from MAVProxy.modules.lib import wxsettings
 from MAVProxy.modules.lib.graphdefinition import GraphDefinition
@@ -476,6 +477,13 @@ def cmd_stats(args):
 def cmd_dump(args):
     '''dump messages from log'''
     global xlimits
+
+    # understand --verbose to give as much information about message as possible
+    verbose = False
+    if "--verbose" in args:
+        verbose = True
+        args = list(filter(lambda x : x != "--verbose", args))
+
     if len(args) > 0:
         wildcard = args[0]
     else:
@@ -497,7 +505,10 @@ def cmd_dump(args):
             continue
         if in_range > 0:
             continue
-        print("%s %s" % (timestring(msg), msg))
+        if verbose and "pymavlink.dialects" in str(type(msg)):
+            mavutil.dump_message_verbose(sys.stdout, msg)
+        else:
+            print("%s %s" % (timestring(msg), msg))
     mlog.rewind()
 
 mfit_tool = None
@@ -862,6 +873,40 @@ def cmd_param_diff(args):
                     s += " (DEFAULT: %s)" % info_default
             print(s)
 
+def cmd_param_save(args, changed_only=False):
+    '''save parameters'''
+    mlog = mestate.mlog
+    if changed_only and not hasattr(mlog, 'param_defaults'):
+        print("No param defaults in log")
+        return
+    filename = args[0]
+    if len(args) > 1:
+        wildcard = args[1]
+    else:
+        wildcard = '*'
+    k = sorted(mlog.params.keys())
+    count = 0
+    try:
+        f = open(filename, "w")
+    except Exception as ex:
+        print("Failed to open %s - %s" % (filename, ex))
+        return
+    for p in k:
+        p = str(p).upper()
+        if changed_only and p in mlog.param_defaults and mlog.params[p] == mlog.param_defaults[p]:
+            continue
+        if fnmatch.fnmatch(p, wildcard.upper()):
+            v = mlog.params[p]
+            if int(v) == v:
+                s = "%-16.16s %d" % (str(p), mlog.params[p])
+            else:
+                s = "%-16.16s %f" % (str(p), mlog.params[p])
+                s = s.rstrip('0')
+            f.write(s + "\n")
+            count += 1
+    f.close()
+    print("Saved %u parameters to %s" % (count, filename))
+            
 def ftp_decode(mlog):
     '''decode FILE_TRANSFER_PROTOCOL for parameters'''
     mlog.rewind()
@@ -959,6 +1004,20 @@ def cmd_param(args):
         if args[0] == 'diff':
             cmd_param_diff(args[1:])
             return
+        if args[0] == 'save':
+            # save parameters
+            if len(args) < 2:
+                print("Usage: param save FILENAME <WILDCARD>")
+                return
+            cmd_param_save(args[1:], False)
+            return
+        if args[0] == 'savechanged':
+            # save changed parameters
+            if len(args) < 2:
+                print("Usage: param savechanged FILENAME <WILDCARD>")
+                return
+            cmd_param_save(args[1:], True)
+            return
         wildcard = args[0]
         if len(args) > 1 and args[1] == "-v":
             verbose = True
@@ -1010,6 +1069,68 @@ def cmd_paramchange(args):
         vmap[pname] = pvalue
     mestate.mlog.rewind()
 
+def cmd_mission(args):
+    '''show mission'''
+    if (len(args) == 1):
+        print("Usage: mission <save FILENAME>")
+        return
+    mestate.mlog.rewind()
+    types = set(['CMD','MISSION_ITEM_INT'])
+    wp = mavwp.MAVWPLoader()
+    while True:
+        m = mestate.mlog.recv_match(type=types, condition=mestate.settings.condition)
+        if m is None:
+            break
+        if m.get_type() == 'CMD':
+            try:
+                frame = m.Frame
+            except AttributeError:
+                print("Warning: assuming frame is GLOBAL_RELATIVE_ALT")
+                frame = mavutil.mavlink.MAV_FRAME_GLOBAL_RELATIVE_ALT
+            num_wps = m.CTot
+            m = mavutil.mavlink.MAVLink_mission_item_message(0,
+                                                             0,
+                                                             m.CNum,
+                                                             frame,
+                                                             m.CId,
+                                                             0, 1,
+                                                             m.Prm1, m.Prm2, m.Prm3, m.Prm4,
+                                                             m.Lat, m.Lng, m.Alt)
+
+        if m.get_type() == 'MISSION_ITEM_INT':
+            m = mavutil.mavlink.MAVLink_mission_item_message(m.target_system,
+                                                             m.target_component,
+                                                             m.seq,
+                                                             m.frame,
+                                                             m.command,
+                                                             m.current,
+                                                             m.autocontinue,
+                                                             m.param1,
+                                                             m.param2,
+                                                             m.param3,
+                                                             m.param4,
+                                                             m.x*1.0e-7,
+                                                             m.y*1.0e-7,
+                                                             m.z)
+        if m.current >= 2:
+            continue
+
+        while m.seq > wp.count():
+            print("Adding dummy WP %u" % wp.count())
+            wp.set(m, wp.count())
+        wp.set(m, m.seq)
+    if len(args) == 2 and args[0] == 'save':
+        wp.save(args[1])
+        mestate.mlog.rewind()
+        return
+    for i in range(wp.count()):
+        w = wp.wp(i)
+        print("%u\t%u\t%u\t%u\t%f\t%f\t%f\t%f\t%f\t\t%f\t\t%f\t%u" % (
+            w.seq, w.current, w.frame, w.command,
+            w.param1, w.param2, w.param3, w.param4,
+            w.x, w.y, w.z, w.autocontinue))
+    mestate.mlog.rewind()
+    
 def cmd_devid(args):
     '''show parameters'''
     params = mestate.mlog.params
@@ -1214,6 +1335,7 @@ command_map = {
     'magfit'     : (cmd_magfit,    'fit mag parameters to WMM'),
     'dump'       : (cmd_dump,      'dump messages from log'),
     'file'       : (cmd_file,      'show files'),
+    'mission'    : (cmd_mission,   'show mission'),
     }
 
 def progress_bar(pct):
